%define api		7
%define major		7
%define libname		%mklibname %{name} %{api} %{major}

%define libplus_major	7
%define libplus		%mklibname mlt++ %{api} %{libplus_major}

%define libnamedev	%mklibname %{name} -d

# We can't distribute MLT with CUDA enabled.
# You have to build it yourself if you want it.
# 0 => don't build with CUDA enabled
# 1 => build with CUDA enabled
%define build_cuda	0

Name:		mlt
Version:	7.6.0
Release:	%mkrel 1
Summary:	Media Lovin' Toolkit
License:	LGPLv2+ and GPLv2+
Group:		Video/Editors and Converters
Url:		https://www.mltframework.org
Source0:	https://github.com/mltframework/mlt/archive/v%{version}/%{name}-%{version}.tar.gz

BuildRequires:	cmake
BuildRequires:	ffmpeg-devel
BuildRequires:	imagemagick
BuildRequires:	ladspa-devel
BuildRequires:	libatomic-devel
BuildRequires:	multiarch-utils >= 1.0.3
BuildRequires:	pkgconfig(libebur128)
BuildRequires:	pkgconfig(fftw3)
BuildRequires:	pkgconfig(frei0r)
BuildRequires:	pkgconfig(glib-2.0)
BuildRequires:	pkgconfig(gtk+-2.0)
BuildRequires:	pkgconfig(jack)
BuildRequires:	pkgconfig(libdv)
BuildRequires:	pkgconfig(libexif)
BuildRequires:	pkgconfig(libquicktime)
BuildRequires:	pkgconfig(libxml-2.0)
BuildRequires:	pkgconfig(mad)
BuildRequires:	pkgconfig(movit)
BuildRequires:	pkgconfig(ogg)
%if %mgaver < 9
BuildRequires:	pkgconfig(opencv)
%endif
BuildRequires:	pkgconfig(pango)
BuildRequires:	pkgconfig(Qt5Core)
BuildRequires:	pkgconfig(Qt5Gui)
BuildRequires:	pkgconfig(Qt5Svg)
BuildRequires:	pkgconfig(Qt5Widgets)
BuildRequires:	pkgconfig(Qt5Xml)
BuildRequires:	pkgconfig(rtaudio)
BuildRequires:	pkgconfig(rubberband)
BuildRequires:	pkgconfig(samplerate)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(sox)
BuildRequires:	pkgconfig(vidstab)
BuildRequires:	pkgconfig(vorbis)
BuildRequires:	qtbase5-common-devel
# For python-bindings
BuildRequires:	swig
BuildRequires:	pkgconfig(python3)
%if %{build_cuda}
BuildRequires: nvidia-cuda-toolkit-devel
BuildRequires: nv-codec-headers
%endif

%description
MLT is an open source multimedia framework, designed and developed for
television broadcasting.

It provides a toolkit for broadcasters, video editors, media players,
transcoders, web streamers and many more types of applications. The
functionality of the system is provided via an assortment of ready to
use tools, xml authoring components, and an extendible plug-in based
API.

%package kdenlive
Summary:	Media Lovin' Toolkit
Group:		Video/Editors and Converters
Conflicts:	%{name} < 0.8.8-2

%description kdenlive
MLT is an open source multimedia framework, designed and developed for
television broadcasting.

It provides a toolkit for broadcasters, video editors, media players,
transcoders, web streamers and many more types of applications. The
functionality of the system is provided via an assortment of ready to
use tools, xml authoring components, and an extendible plug-in based
API.

This package contains plugins aimed to be used by kde apps.

%package -n %{libname}
Summary:	Main library for mlt
Group:		System/Libraries
Obsoletes:	%{_lib}mlt7 < 7.4.0-3

%description -n %{libname}
This package contains the libraries needed to run programs dynamically
linked with mlt.

%package -n %{libplus}
Summary:	Main library for mlt++
Group:		System/Libraries
Obsoletes:	%{_lib}mlt++7 < 7.4.0-3

%description -n %{libplus}
This package contains the libraries needed to run programs dynamically
linked with mlt++.

%package -n %{libnamedev}
Summary:	Headers for developing programs that will use mlt
Group:		Development/C
Requires:	%{libname} = %{version}-%{release}
Requires:	%{libplus} = %{version}-%{release}
# mlt-config requires stuff from %%{_datadir}/%%{name}
Requires:	%{name} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}
Provides:	%{name}++-devel = %{version}-%{release}
Provides:	lib%{name}++-devel = %{version}-%{release}

%description -n %{libnamedev}
This package contains the headers that programmers will need to develop
applications which will use mlt.

%package -n python3-%{name}
Summary:	Python 3 bindings for MLT
Group:		Development/Python
Requires:	python3
Requires:	%{name} = %{version}-%{release}

Obsoletes:	python2-mlt < 6.18.0
Provides:	python-mlt = %{version}-%{release}

%description -n python3-%{name}
This module allows to work with MLT using python 3.

%prep
%autosetup -p1

%build
%cmake \
%ifnarch x86_64
	-DCPU_MMX:BOOL=OFF \
	-DCPU_SSE:BOOL=OFF \
	-DCPU_SSE2:BOOL=OFF \
%endif
%if %{build_cuda}
	-DMOD_NDI:BOOL=ON \
	-DNDI_SDK_INCLUDE_PATH:PATH=%{_includedir} \
	-DNDI_SDK_LIBRARY_PATH:PATH=%{_libdir} \
%endif
	-DCMAKE_SKIP_RPATH:BOOL=ON \
	-DGPL:BOOL=ON \
	-DGPL3:BOOL=ON \
%if %mgaver < 9
	-DMOD_OPENCV:BOOL=ON \
%else
	-DMOD_OPENCV:BOOL=OFF \
%endif
	-DMOD_KDENLIVE:BOOL=ON \
	-DSWIG_PYTHON:BOOL=ON

%cmake_build

%install
%cmake_install
#man page
install -Dpm644 docs/melt.1 %{buildroot}%{_mandir}/man1/melt.1


%files
%doc docs/*.txt README.md
%license COPYING
%{_bindir}/melt
%{_bindir}/melt-%{api}
%{_datadir}/mlt-%{api}
%{_libdir}/mlt-%{api}/
%{_mandir}/man1/melt.1*
%{_mandir}/man1/melt-%{api}.1*
%exclude %{_libdir}/mlt-%{api}/libmltkdenlive.so

%files kdenlive
%{_libdir}/mlt-%{api}/libmltkdenlive.so

%files -n %{libname}
%{_libdir}/libmlt-%{api}.so.%{major}{,.*}
%{_libdir}/libmlt-%{api}.so.%{version}

%files -n %{libplus}
%{_libdir}/libmlt++-%{api}.so.%{libplus_major}{,.*}
%{_libdir}/libmlt++-%{api}.so.%{version}

%files -n %{libnamedev}
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/Mlt%{api}

%files -n python3-%{name}
%{python3_sitearch}/*


%changelog
* Tue Mar 29 2022 kekepower <kekepower> 7.6.0-1.mga9
+ Revision: 1833135
- Update to version 7.6.0

* Sun Mar 13 2022 mrambo3501 <mrambo3501> 7.4.0-5.mga9
+ Revision: 1790702
- rebuild for ffmpeg 5.0

* Mon Feb 28 2022 tv <tv> 7.4.0-4.mga9
+ Revision: 1786772
- Rebuild for python-3.10

* Sat Jan 01 2022 wally <wally> 7.4.0-3.mga9
+ Revision: 1765665
- fix lib pkg names
- add mlt++ provides to devel pkg

* Mon Dec 27 2021 ghibo <ghibo> 7.4.0-2.mga9
+ Revision: 1764580
- Temporarily disable opencv support for cauldron, waiting for protobuf to be rebuilt/upgraded.

* Mon Dec 27 2021 ghibo <ghibo> 7.4.0-1.mga9
+ Revision: 1764362
- skip rpath
- Update to release 7.4.0.
- Switch to cmake
- Add new BuildRequires.

* Wed Apr 14 2021 kekepower <kekepower> 6.26.1-1.mga9
+ Revision: 1715797
- Update to version 6.26.1

* Sat Apr 10 2021 kekepower <kekepower> 6.26.0-1.mga9
+ Revision: 1714622
- Update to version 6.26.0
- Add option to build with CUDA enabled

* Sun Mar 28 2021 daviddavid <daviddavid> 6.24.0-5.mga9
+ Revision: 1711441
- rebuild for python 3.9

* Sun Mar 07 2021 ghibo <ghibo> 6.24.0-4.mga9
+ Revision: 1700459
- Bump release (because forgotten at previous commit)
- Disable SSE too for %%ix86 (AKA i586), fixes also kdenlive segfaulting on pure i586 at startup.

* Fri Mar 05 2021 kekepower <kekepower> 6.24.0-3.mga9
+ Revision: 1699894
- Only a small set of ix86 CPUs support MMX. Enable it for x86_64 only

* Thu Dec 17 2020 umeabot <umeabot> 6.24.0-2.mga8
+ Revision: 1659060
- Rebuild for new Qt5

* Sat Dec 12 2020 kekepower <kekepower> 6.24.0-1.mga8
+ Revision: 1655789
- Update to version 6.24.0

* Sun Aug 02 2020 kekepower <kekepower> 6.22.1-1.mga8
+ Revision: 1610457
- Update to version 6.22.1

* Thu Jul 09 2020 daviddavid <daviddavid> 6.20.0-3.mga8
+ Revision: 1603216
- add upstream patch to fix build with Qt 5.15.0
+ zezinho <zezinho>
- rebuild against ffmpeg 4.3

* Fri May 01 2020 zezinho <zezinho> 6.20.0-2.mga8
+ Revision: 1577615
- enable rubberband

* Sat Feb 29 2020 zezinho <zezinho> 6.20.0-1.mga8
+ Revision: 1552197
- new version

* Tue Feb 18 2020 umeabot <umeabot> 6.18.0-2.mga8
+ Revision: 1538304
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Mon Nov 18 2019 zezinho <zezinho> 6.18.0-1.mga8
+ Revision: 1461678
- new version

* Fri Aug 02 2019 zezinho <zezinho> 6.16.0-1.mga8
+ Revision: 1426894
- new version 6.16

* Fri Aug 02 2019 zezinho <zezinho> 6.14.0-2.mga8
+ Revision: 1426888
- add BR vidstab to fix mga#25093wq

* Wed Apr 10 2019 zezinho <zezinho> 6.14.0-1.mga7
+ Revision: 1387938
- new version 6.14

* Sun Mar 31 2019 umeabot <umeabot> 6.12.0-2.mga7
+ Revision: 1383459
- Qt5 Rebuild

* Thu Dec 13 2018 zezinho <zezinho> 6.12.0-1.mga7
+ Revision: 1341097
- new version 6.12.0

* Sat Aug 25 2018 zezinho <zezinho> 6.10.0-1.mga7
+ Revision: 1254404
- new version 6.10.0

* Mon May 28 2018 akien <akien> 6.8.0-1.mga7
+ Revision: 1232769
- Version 6.8.0

* Mon Apr 23 2018 zezinho <zezinho> 6.6.0-5.mga7
+ Revision: 1221700
- rebuild against ffmpeg 4

* Mon Feb 26 2018 daviddavid <daviddavid> 6.6.0-4.mga7
+ Revision: 1205367
- fix version of obsoleted python-mlt

* Mon Feb 26 2018 daviddavid <daviddavid> 6.6.0-3.mga7
+ Revision: 1205298
- rebuild for new movit
- rename python-mlt to python2-mlt

* Thu Feb 01 2018 zezinho <zezinho> 6.6.0-2.mga7
+ Revision: 1198513
- enable MMX and SSE1 in x86

* Thu Feb 01 2018 zezinho <zezinho> 6.6.0-1.mga7
+ Revision: 1198477
- new version

* Thu Aug 24 2017 ovitters <ovitters> 6.4.1-3.mga7
+ Revision: 1145167
+ rebuild (emptylog)

* Tue May 02 2017 akien <akien> 6.4.1-3.mga6
+ Revision: 1098310
- Rebuild for ffmpeg 3.3

* Sat Jan 21 2017 zezinho <zezinho> 6.4.1-2.mga6
+ Revision: 1082861
- enable Movit Gpu Effects

* Sat Jan 21 2017 zezinho <zezinho> 6.4.1-1.mga6
+ Revision: 1082702
- new version 6.4.1

* Tue May 10 2016 zezinho <zezinho> 6.2.0-1.mga6
+ Revision: 1012358
- new version 6.2.0

* Mon Feb 15 2016 umeabot <umeabot> 0.9.8-8.mga6
+ Revision: 961463
- Mageia 6 Mass Rebuild

* Fri Sep 11 2015 daviddavid <daviddavid> 0.9.8-7.mga6
+ Revision: 876945
- rebuild for new sox 14.4.2

* Mon Sep 07 2015 sander85 <sander85> 0.9.8-6.mga6
+ Revision: 873947
- Bring back qimage

* Tue Aug 25 2015 sander85 <sander85> 0.9.8-5.mga6
+ Revision: 869306
- Build with Qt5

* Fri Jul 31 2015 wally <wally> 0.9.8-4.mga6
+ Revision: 860099
- install man page
- use %%license for COPYING

* Fri Jul 31 2015 wally <wally> 0.9.8-3.mga6
+ Revision: 860053
- BR fftw-devel

* Fri Jul 31 2015 wally <wally> 0.9.8-2.mga6
+ Revision: 860047
- enable GPLv3 components

* Fri Jul 31 2015 wally <wally> 0.9.8-1.mga6
+ Revision: 859948
- new version 0.9.8
- update URL
+ akien <akien>
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 umeabot <umeabot> 0.9.2-4.mga5
+ Revision: 748641
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.9.2-3.mga5
+ Revision: 727337
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.9.2-2.mga5
+ Revision: 682547
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 juancho <juancho> 0.9.2-1.mga5
+ Revision: 670322
- Updated to version 0.9.2

* Sun Jul 06 2014 fwang <fwang> 0.9.0-3.mga5
+ Revision: 644179
- fix build with recent freetype
+ pterjan <pterjan>
- Rebuild for new Python

* Sat Oct 19 2013 umeabot <umeabot> 0.9.0-2.mga4
+ Revision: 529702
- Mageia 4 Mass Rebuild

* Thu Jul 11 2013 fwang <fwang> 0.9.0-1.mga4
+ Revision: 452914
- bump libmajor
- new version 0.9.0

* Mon Feb 04 2013 fwang <fwang> 0.8.8-3.mga3
+ Revision: 394478
- add conflicts to ease upgrading

* Mon Feb 04 2013 neoclust <neoclust> 0.8.8-2.mga3
+ Revision: 394470
- Try to remove kde deps out of main package

* Wed Jan 30 2013 zezinho <zezinho> 0.8.8-1.mga3
+ Revision: 393528
- new version

* Tue Jan 29 2013 cjw <cjw> 0.8.6-4.mga3
+ Revision: 393221
- patch1 from mlt git: fix audio decoding with ffmpeg 1.1

* Sat Jan 12 2013 umeabot <umeabot> 0.8.6-3.mga3
+ Revision: 360171
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Tue Jan 08 2013 fwang <fwang> 0.8.6-2.mga3
+ Revision: 341726
- rebuild for new ffmpeg

* Thu Nov 29 2012 juancho <juancho> 0.8.6-1.mga3
+ Revision: 322924
- Updated group to comply with new RPM group policy.
- Updated to 0.8.6

* Wed Sep 12 2012 fwang <fwang> 0.8.2-1.mga3
+ Revision: 292515
- new version 0.8.2

* Mon Jul 30 2012 fwang <fwang> 0.8.0-2.mga3
+ Revision: 275947
- rebuild for new sox

* Fri Jun 15 2012 fwang <fwang> 0.8.0-1.mga3
+ Revision: 260700
- update libamjor
- new version 0.8.0

* Wed May 30 2012 fwang <fwang> 0.7.8-3.mga3
+ Revision: 249674
- rebuild for new ffmpeg

* Sun Apr 08 2012 sander85 <sander85> 0.7.8-2.mga2
+ Revision: 229720
- fix some audio codecs not detected with newer libavcodec

* Mon Feb 27 2012 fwang <fwang> 0.7.8-1.mga2
+ Revision: 215634
- drop more internal sybol
- new version 0.7.8

* Tue Dec 27 2011 dmorgan <dmorgan> 0.7.6-2.mga2
+ Revision: 188252
- Do not use ffmeg private symbols ( mga #3732)

* Tue Nov 01 2011 fwang <fwang> 0.7.6-1.mga2
+ Revision: 160763
- new version 0.7.6
- new version 0.7.4

* Mon Jul 04 2011 ahmad <ahmad> 0.7.2-3.mga2
+ Revision: 118265
- Add BR frei0r-devel

* Sat Jun 25 2011 fwang <fwang> 0.7.2-2.mga2
+ Revision: 113451
- rebuild for new ffmpeg

* Tue May 17 2011 dmorgan <dmorgan> 0.7.2-1.mga1
+ Revision: 99445
- New version 0.7.2

* Thu Feb 17 2011 wally <wally> 0.6.2-1.mga1
+ Revision: 53196
- new version 0.6.2
- new major 3
- fix license and summary
- drop old obsoletes
- clean .spec
- imported package mlt


* Thu Nov 04 2010 Götz Waschk <waschk@mandriva.org> 0.5.10-2mdv2011.0
+ Revision: 593364
- rebuild for new python 2.7

* Wed Sep 15 2010 Funda Wang <fwang@mandriva.org> 0.5.10-1mdv2011.0
+ Revision: 578422
- new version 0.5.10

* Sat Aug 07 2010 Ahmad Samir <ahmadsamir@mandriva.org> 0.5.6-1mdv2011.0
+ Revision: 567229
- update to 0.5.6

* Tue Feb 16 2010 Frederik Himpe <fhimpe@mandriva.org> 0.5.0-1mdv2010.1
+ Revision: 506848
- update to new version 0.5.0

* Wed Jan 13 2010 Stéphane Téletchéa <steletch@mandriva.org> 0.4.10-3mdv2010.1
+ Revision: 490979
- Adjust python path in the files section
- Add python bindings
- Add missing ogg BR
- Add conditional build for MMX and SSE support
- Small indentation fixes
- Update configure parameters

* Thu Dec 10 2009 Frederik Himpe <fhimpe@mandriva.org> 0.4.10-1mdv2010.1
+ Revision: 476119
- update to new version 0.4.10

* Fri Oct 09 2009 Funda Wang <fwang@mandriva.org> 0.4.6-1mdv2010.0
+ Revision: 456244
- New version 0.4.6

* Sat Jul 04 2009 Frederik Himpe <fhimpe@mandriva.org> 0.4.4-1mdv2010.0
+ Revision: 392365
- update to new version 0.4.4

* Mon Jun 01 2009 Funda Wang <fwang@mandriva.org> 0.4.2-2mdv2010.0
+ Revision: 381769
- fix requires

* Mon Jun 01 2009 Funda Wang <fwang@mandriva.org> 0.4.2-1mdv2010.0
+ Revision: 381761
- New version 0.4.2

* Fri May 01 2009 Funda Wang <fwang@mandriva.org> 0.3.8-1mdv2010.0
+ Revision: 369393
- try to simplify underlink patch
- New version 0.3.8

* Tue Feb 03 2009 Funda Wang <fwang@mandriva.org> 0.3.6-1mdv2009.1
+ Revision: 336764
- New version 0.3.6

* Wed Dec 31 2008 Funda Wang <fwang@mandriva.org> 0.3.4-1mdv2009.1
+ Revision: 321589
- rediff noO3 patch
- New version 0.3.4
- drop sox patch (merged upstream)
- disable ppc patch (we do not support it officially)

  + Oden Eriksson <oeriksson@mandriva.com>
    - lowercase ImageMagick

* Mon Nov 17 2008 Funda Wang <fwang@mandriva.org> 0.3.2-2mdv2009.1
+ Revision: 303891
- add sox 14.2.0 patch from upstream

* Tue Nov 11 2008 Funda Wang <fwang@mandriva.org> 0.3.2-1mdv2009.1
+ Revision: 302079
- New version 0.3.2

* Tue Oct 14 2008 Adam Williamson <awilliamson@mandriva.org> 0.3.1-0.svn1184.1mdv2009.1
+ Revision: 293781
- bump snapshot to fix build with latest ffmpeg
- rebuild for new ffmpeg major

* Wed Sep 10 2008 Stéphane Téletchéa <steletch@mandriva.org> 0.3.1-0.svn1180.3mdv2009.0
+ Revision: 283525
- re-enabling sox, it works correctly now

* Tue Sep 09 2008 Stéphane Téletchéa <steletch@mandriva.org> 0.3.1-0.svn1180.2mdv2009.0
+ Revision: 283342
- update Obsoletes to ease migration from previous release

* Tue Sep 09 2008 Stéphane Téletchéa <steletch@mandriva.org> 0.3.1-0.svn1180.1mdv2009.0
+ Revision: 283341
- update to latest svn revision
- fix the svn case for a smoother upgrade
- update to latest svn revision to build a working kdenlive

* Wed Sep 03 2008 Helio Chissini de Castro <helio@mandriva.com> 0.3.0-2mdv2009.0
+ Revision: 279971
- We have qt4 in main and kdenlive is qt4, so make library qt3 not helps in any way. This fix startup crashes on kdenlive
- Clean the redefinitions in spec
- Kill all hack to enable and patch and disable and buildconflicts where just a --disable-sox would work

* Wed Aug 06 2008 Funda Wang <fwang@mandriva.org> 0.3.0-1mdv2009.0
+ Revision: 264227
- add sox detection patch
- disable sox build as mlt 0.3 does not like sox 14.1
- more underlink patch
- update libmajor
- New version 0.3.0
- apply underlink patch
- fix under llink

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

* Sat Feb 02 2008 Austin Acton <austin@mandriva.org> 0.2.5-0.20080123.2mdv2008.1
+ Revision: 161308
- rebuild for new libsox

* Wed Jan 23 2008 Giuseppe Ghibò <ghibo@mandriva.com> 0.2.5-0.20080123.1mdv2008.1
+ Revision: 156997
- Update to mlt svn 20080123 (for bug #36896).

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Nov 19 2007 Adam Williamson <awilliamson@mandriva.org> 0.2.4-3mdv2008.1
+ Revision: 110562
- buildrequires libjack-devel (#33601)

* Wed Sep 05 2007 Funda Wang <fwang@mandriva.org> 0.2.4-2mdv2008.0
+ Revision: 80185
- Obsoletes old devel package

* Sun Aug 12 2007 Funda Wang <fwang@mandriva.org> 0.2.4-1mdv2008.0
+ Revision: 62171
- drop patch5, not needed
- drop patch4, merged upstream
- Drop patch3, merged upstream
- New version 0.2.4


* Tue Mar 13 2007 Giuseppe Ghibò <ghibo@mandriva.com> 0.2.2-9mdv2007.1
+ Revision: 142397
- Rebuilt against latest ffmpeg.

* Mon Mar 12 2007 Giuseppe Ghibò <ghibo@mandriva.com> 0.2.2-8mdv2007.1
+ Revision: 141637
- Don't revert gb PPC patch.
- Better handling of avformat-swscale (for now disabled).

* Sun Mar 11 2007 Giuseppe Ghibò <ghibo@mandriva.com> 0.2.2-7mdv2007.1
+ Revision: 141361
- Unbzip2 patches.
- Added Patch3 from cvs (fix motion-est for x86_64).
- Added Patch4 to build with sox 13 (fix bug #29207).
- Added Patch5 (to enable --avformat-swscale).

  + Gwenole Beauchesne <gbeauchesne@mandriva.com>
    - lib{32,64} fixes

* Mon Dec 18 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 0.2.2-6mdv2007.1
+ Revision: 98492
- fix patch2: enable SSE optimizations for x86-64
- drop BuildRequires libavifile-devel (not used)
- patch2: fix build on ppc

* Mon Oct 30 2006 Anssi Hannula <anssi@mandriva.org> 0.2.2-5mdv2007.1
+ Revision: 73837
- buildrequires mad-devel
- buildrequires ImageMagick
- rebuild
- drop unused plf build switch
  fix invalid provides of libpackage
  fix requires of devel package

  + Andreas Hasenack <andreas@mandriva.com>
    - commit on behalf of Giuseppe Ghib?\195?\178 to get package in sync with svn:
      * Wed Sep 13 2006 Giuseppe Ghib?\195?\178 <ghibo@mandriva.com> 0.2.2-2mdv2007.0
      - Fix build for X86_64.
      - Fixed License.
      - Removed suffix in configure, so to let modules avformat built.

  + Jerome Martin <jmartin@mandriva.org>
    - import mlt-0.2.2-0.1.20060mdk

* Wed Jun 21 2006 Jerome Martin <jmartin@mandriva.org> 0.2.2-1
- Initial version

